# Cytron MAKER PI PICO board - Data Logging
# BME680 with SSD1306 - uses both I2C buses
# Tony Goodhew 13 April 2021
# CircuitPython with Adafruit libraries
import time
import digitalio
import board
import sdcardio
import storage
import busio
import displayio
import adafruit_bme680
import adafruit_ssd1306
from neopixel_write import neopixel_write
displayio.release_displays() # Saves a load of trouble
# Essential user values
filename = "/sd/log9.txt"
interval = 3.0 # Seconds between readings
temperature_offset = 0 # Checked at 22 Celsius

# Initialize STOP button - LEFT button
stop = digitalio.DigitalInOut(board.GP20)
stop.switch_to_input(pull=digitalio.Pull.UP)

# Create the I2C interface
i2c0 = busio.I2C (scl=board.GP1, sda=board.GP0) # SSD1306 Display
display_bus = displayio.I2CDisplay (i2c0, device_address = 0x3C)
# Set up SSD1306 OLED display
oled = adafruit_ssd1306.SSD1306_I2C(128, 64, i2c0)
# Clear the display.
oled.fill(0)
oled.text("BME 680",25,30,1)
oled.show()

# Set up Neopixel
RGB = digitalio.DigitalInOut(board.GP28)
RGB.direction = digitalio.Direction.OUTPUT
neopixel_write(RGB, bytearray([0,0,20])) # LED BLUE

# Set up BME680
i2c1 = busio.I2C (scl=board.GP7, sda=board.GP6) # BME680 Sensor
bme680 = adafruit_bme680.Adafruit_BME680_I2C(i2c1, debug=False)
# change this to match the location's pressure (hPa) at sea level
bme680.sea_level_pressure = 1027.0

# Set up SD card reader
DS_CS = board.GP15
spi = busio.SPI(board.GP10, board.GP11, board.GP12)
sd = sdcardio.SDCard(spi, board.GP15)
neopixel_write(RGB, bytearray([0,20,0])) # LED RED
vfs = storage.VfsFat(sd)
storage.mount(vfs, '/sd')
outstring = str(interval) +","+str(interval)+"\r\n"
with open(filename, "w") as file: # write
        file.write(outstring)
# === Main Loop ===
running = True
while running:
    neopixel_write(RGB, bytearray([20,0,0])) # LED GREEN
    loop_on = time.monotonic() + interval
    # Get values from sensor and display to Serial Monitor and SSD1306
    print("\nTemperature: %0.1f C" % (bme680.temperature + temperature_offset))
    print("Gas: %d ohm" % bme680.gas)
    print("Humidity: %0.1f %%" % bme680.relative_humidity)
    print("Pressure: %0.3f hPa" % bme680.pressure)
    print("Altitude = %0.2f metres" % bme680.altitude)
    oled.fill(0)
    oled.text("Temperature: %0.1f C" % (bme680.temperature + temperature_offset),0,5,1)
    oled.text("Gas: %d ohm" % bme680.gas,0,16,1)
    oled.text("Humidity: %0.1f %%" % bme680.relative_humidity,0,27,1)
    oled.text("Pressure: %0.2f hPa" % bme680.pressure,0,38,1)
    oled.text("Altitude: %0.2f m" % bme680.altitude,0,49,1)
    oled.show()

    # Save temperature and humidity to file (1 decimal place)
    neopixel_write(RGB, bytearray([0,20,0])) # LED RED
    t = (int((bme680.temperature + temperature_offset) * 10.0))/10.0
    h = (int((bme680.relative_humidity) * 10.0))/10.0
    outstring = str(t) +","+str(h)+"\r\n" # Create file record - a line
    with open(filename, "a") as file: # append
        file.write(outstring)

    neopixel_write(RGB, bytearray([20,0,0])) # LED GREEN
    while running and time.monotonic() < loop_on:
        if stop.value == 0: # Check STOP button
            running = False

# === Finished so Tidy up ===
# Write rogue values to file
neopixel_write(RGB, bytearray([0,20,20])) # LED MAGENTA
outstring = str(-999.0) +","+str(-999.0)+"\r\n"
with open(filename, "a") as file:
    file.write(outstring)
time.sleep(0.3)
oled.fill(0)
oled.text("All Done", 40, 30, 1)
oled.show()
time.sleep(2)
# Clear screen
oled.fill(0)
oled.show()
neopixel_write(RGB, bytearray([0,0,0])) # LED OFF
print("Finished")